@@ -37,6 +37,7 @@ from .actions import (
     scan,
     streaming_bulk,
 )
+from .asyncsigner import AWSV4SignerAsyncAuth
 from .errors import BulkIndexError, ScanError
 from .signer import AWSV4SignerAuth
 
@@ -52,6 +53,7 @@ __all__ = [
     "_chunk_actions",
     "_process_bulk_chunk",
     "AWSV4SignerAuth",
+    "AWSV4SignerAsyncAuth",
 ]
 
 
